/*
 * Copyright (C) 2007 The GNOME Foundation
 * Written by Thomas Wood <thos@gnome.org>
 *            Jens Granseuer <jensgr@gmx.net>
 * All Rights Reserved
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GTKRC_UTILS_H__
#define __GTKRC_UTILS_H__

void gtkrc_get_details (gchar *filename, GSList **engines, GSList **symbolic_colors);
gchar * gtkrc_find_named (const gchar *name);
gchar * gtkrc_get_color_scheme (const gchar *filename);
gchar * gtkrc_get_color_scheme_for_theme (const gchar *theme_name);

#endif /* __GTKRC_UTILS_H__ */
